[−][src]Struct specs::storage::MaskedStorage

pub struct MaskedStorage<T: Component> { /* fields omitted */ }

The UnprotectedStorage together with the BitSet that knows about which elements are stored, and which are not.

Methods

impl<T: Component> MaskedStorage<T>[src]

pub fn new(inner: T::Storage) -> MaskedStorage<T>[src]

Creates a new MaskedStorage. This is called when you register a new component type within the world.

pub fn clear(&mut self)[src]

Clear the contents of this storage.

pub fn remove(&mut self, id: Index) -> Option<T>[src]

Remove an element by a given index.

pub fn drop(&mut self, id: Index)[src]

Drop an element by a given index.